@@ -4,18 +4,38 @@ Created on 14.04.2011
 
 @author: kirov
 '''
-from __future__ import absolute_import
+from __future__ import (
+    absolute_import,
+)
+
+import codecs
+import csv
 import os
 import uuid
-import csv
-import codecs
-from functools import cmp_to_key
+from functools import (
+    cmp_to_key,
+)
 
-from django.conf import settings
-from django.db.models import Q, Count, Avg, Max, Min, Sum
 import six
-from six.moves import range
-from m3_legacy import compare
+from django.db.models import (
+    Avg,
+    Count,
+    Max,
+    Min,
+    Q,
+    Sum,
+)
+from six.moves import (
+    range,
+)
+
+from m3_legacy import (
+    compare,
+)
+from m3_legacy.config import (
+    get_downloads_dir,
+    get_downloads_url,
+)
 
 
 try:
@@ -389,7 +409,7 @@ class GroupingRecordProvider(object):
         """
         return worksheet
 
-    def export_to_xls (self, title, columns, total, grouped, expanded, sorting):
+    def export_to_xls(self, title, columns, total, grouped, expanded, sorting):
         """
         Выгрузка таблицы в xls-файл
         """
@@ -397,16 +417,20 @@ class GroupingRecordProvider(object):
         ws = w.add_sheet('grid')
         ws = self._tune_xls_worksheet(ws)
 
-        title_style = xlwt.easyxf(self.xls_style.get(
-            'title') or "font: bold on, height 400;")
-        header_style = xlwt.easyxf(self.xls_style.get('header') or
-                                   "font: bold on, color-index white;"
-                                   "borders: left thick, right thick, top thick, bottom thick;"
-                                   "pattern: pattern solid, fore_colour gray80;"
-                                   )
-        data_style = xlwt.easyxf(self.xls_style.get('data') or
-                                 "borders: left thin, right thin, top thin, bottom thin;"
-                                 )
+        title_style = xlwt.easyxf(
+            self.xls_style.get('title') or
+            "font: bold on, height 400;"
+        )
+        header_style = xlwt.easyxf(
+            self.xls_style.get('header') or
+            "font: bold on, color-index white;"
+            "borders: left thick, right thick, top thick, bottom thick;"
+            "pattern: pattern solid, fore_colour gray80;"
+        )
+        data_style = xlwt.easyxf(
+            self.xls_style.get('data') or
+            "borders: left thin, right thin, top thin, bottom thin;"
+        )
 
         col_count = 0
         total_width = 0
@@ -460,10 +484,10 @@ class GroupingRecordProvider(object):
 
         base_name = str(uuid.uuid4())[0:16] + '.xls'
 
-        xls_file_abs = os.path.join(settings.MEDIA_ROOT, base_name)
+        xls_file_abs = os.path.join(get_downloads_dir(), base_name)
         w.save(xls_file_abs)
         join = lambda pieces: u'/'.join(s.strip('/') for s in pieces)
-        url = join([settings.MEDIA_URL, base_name])
+        url = join([get_downloads_url(), base_name])
         return url
 
     def export_to_csv(self, title, columns, total, grouped, expanded, sorting):
@@ -471,7 +495,7 @@ class GroupingRecordProvider(object):
         выгрузка таблицы в csv-файл
         '''
         base_name = str(uuid.uuid4())[0:16] + '.csv'
-        file_abs = os.path.join(settings.MEDIA_ROOT, base_name)
+        file_abs = os.path.join(get_downloads_dir(), base_name)
         # ws = UnicodeWriter(open(file_abs, 'wb'), delimiter='|',
         # quotechar='"', quoting=csv.QUOTE_MINIMAL)
         ws = UnicodeWriter(open(
@@ -525,7 +549,7 @@ class GroupingRecordProvider(object):
             ws.writerow(row)
 
         join = lambda pieces: u'/'.join(s.strip('/') for s in pieces)
-        url = join([settings.MEDIA_URL, base_name])
+        url = join([get_downloads_url(), base_name])
         return url
 
 
