@@ -3,56 +3,14 @@
 from __future__ import absolute_import
 import datetime
 
-from django.db import models, connection, router, connections
+from django.db import models, router, connections
 from django.db.models.deletion import Collector
 from django.db.models.query import QuerySet
 from m3 import json_encode
-from m3_django_compat import atomic
+from m3.db import safe_delete
 import six
 
 
-def safe_delete(model):
-    """
-    Функция выполняющая "безопасное" удаление записи из БД.
-    В случае, если удаление не удалось по причине нарушения целостности,
-    то возвращается false. Иначе, true
-    к тому же функция пересчитывает MPTT индексы дерева
-    т.к. стандартный пересчет запускается при вызове model_instance.delete()
-    """
-    try:
-        with atomic():
-            models.signals.pre_delete.send(
-                sender=model.__class__, instance=model
-            )
-
-            cursor = connection.cursor()  # @UndefinedVariable
-            sql = "DELETE FROM %s WHERE id = %s" % (connection.ops.quote_name(
-                model._meta.db_table), model.id)  # @UndefinedVariable
-            cursor.execute(sql)
-    except Exception as e:
-        # Встроенный в Django IntegrityError не генерируется.
-        # Кидаются исключения, специфичные для каждого драйвера БД.
-        # Но по спецификации PEP 249 все они называются IntegrityError
-        if e.__class__.__name__ == 'IntegrityError':
-            return False
-        raise
-
-    # добавим пересчет mptt дерева
-    # (т.к. стандартный пересчет вешается на метод self.delete()
-    if hasattr(model, '_tree_manager') and callable(
-            getattr(model._tree_manager, '_close_gap', None)):
-        # это видимо mptt моедль
-        opts = model._meta
-        tree_width = (getattr(model, opts.right_attr) -
-                      getattr(model, opts.left_attr) + 1)
-        target_right = getattr(model, opts.right_attr)
-        tree_id = getattr(model, opts.tree_id_attr)
-        model._tree_manager._close_gap(tree_width, target_right, tree_id)
-
-    models.signals.post_delete.send(sender=model.__class__, instance=model)
-    return True
-
-
 def queryset_limiter(queryset, start=0, limit=0):
     """
     "Вырезает" из QuerySet'a записи начиная с позиции start
